<?xml version="1.0" ?>
<!--                                                            -->
<!-- VISA Invoice Style Sheet version 1.0                       -->
<!--                                                            -->
<!-- DESCRIPTION                                                -->
<!-- Generic stylesheet for VISA XML Invoice DTD 1.0            -->
<!--                                                            -->
<!-- Author: Martin Bell                                        -->
<!-- Copyright (C) 2000, Visa International Service Association -->
<!-- All rights reserved.                                       -->
<!--                                                            -->
<!-- CHANGE HISTORY                                             -->
<!-- 2000-01-14  Revision 1.0   Release Version                 -->
<!--                                                            -->
<!-- NOTICE:  Permission to copy and implement the material     -->
<!-- contained herein is granted only pursuant to separate      -->
<!-- license from Visa International Service Association, and   -->
<!-- is subject to the conditions that                          -->
<!-- (i) any copy or re-publication must bear this legend in    -->
<!--     full,                                                  -->
<!-- (ii) any derivative work must bear a notice that it is not -->
<!--     the XML Invoice Specification published by Visa,       -->
<!--  and                                                       -->
<!-- (iii) Visa shall have no responsibility or liability       -->
<!--     whatsoever to any other party arising from the use or  -->
<!--     publication of the material contained herein.          -->
<!--                                                            -->
<xsl:stylesheet language="VBScript" xmlns:xsl="http://www.w3.org/TR/WD-xsl">

<!-- The following Section provides date and time formatting functions -->

<!-- Time Formatting Function -->
  <xsl:script language="VBScript">
    Function TimeFormat(TimeStr)
      TimeFormat = (Mid(TimeStr,12,8))
    End Function
  </xsl:script>

<!-- ShortTime Formatting Function -->
  <xsl:script language="VBScript">
    Function ShortTimeFormat(TimeStr)
      ShortTimeFormat = (Mid(TimeStr,12,5))
    End Function
  </xsl:script>

<!-- New Date Formatting Function -->
  <xsl:script language="VBScript">
    Function DateFormat(DateStr)
      DateFormat = (Mid(DateStr,9,2)+"/"+Mid(DateStr,6,2)+"/"+Left(DateStr,4))
    End Function
  </xsl:script>

  <xsl:script language="VBScript">
    Function QtyFormat(AmtStr)
	If IsNull(AmtStr) or IsEmpty(AmtStr) OR LEN(TRIM(AmtStr)) = 0 Then
		QtyFormat   = AmtStr
	Else
	      QtyFormat = FormatNumber(CDbl(AmtStr),1)
	End If
    End Function
  </xsl:script>

  <xsl:script language="VBScript">
    Function AsIsFormat(AmtStr)
		AsIsFormat = AmtStr
    End Function
  </xsl:script>

  <xsl:script language="VBScript">
    Function MoneyFormat(AmtStr)
	If IsNull(AmtStr) or IsEmpty(AmtStr)Then
		MoneyFormat = AmtStr
	Else
	      MoneyFormat = FormatNumber(CDbl(AmtStr),2)
	End If
    End Function
  </xsl:script>

  <xsl:script language="VBScript">
    Function PercentFormat(AmtStr)
	If IsNull(AmtStr) or IsEmpty(AmtStr)Then
		PercentFormat  = AmtStr
	Else
	      PercentFormat = FormatNumber(CDbl(AmtStr),2)
	End If
    End Function
  </xsl:script>
<!-- The remainder is the formatting for the document -->

<xsl:template match="/">

<html>

<xsl:for-each select="Invoice">
<head>
<title>Visa Invoice</title>

<xsl:choose>
	<xsl:when test="InvoiceHeader/InvoiceType[@stdValue='381']">
		<xsl:choose>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='AI']"><h1 align="center"><font color="navy"><u>VISA AIRLINE CREDIT NOTE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='LG']"><h1 align="center"><font color="navy"><u>VISA HOTEL CREDIT NOTE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='CR']"><h1 align="center"><font color="navy"><u>VISA CAR RENTAL CREDIT NOTE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='HC']"><h1 align="center"><font color="navy"><u>VISA HEALTH CARE CREDIT NOTE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='IG']"><h1 align="center"><font color="navy"><u>VISA GOVERNMENT CREDIT NOTE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='TS']"><h1 align="center"><font color="navy"><u>VISA TEMPORARY SUPPLIER CREDIT NOTE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='MM']"><h1 align="center"><font color="navy"><u>VISA MISCELLANEOUS SUPPLIER CREDIT NOTE</u></font></h1></xsl:when>
			<xsl:otherwise><h1 align="center"><font color="navy"><u>VISA INVOICE</u></font></h1></xsl:otherwise>
		</xsl:choose>
	</xsl:when>
	<xsl:otherwise>
		<xsl:choose>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='AI']"><h1 align="center"><font color="navy"><u>VISA AIRLINE INVOICE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='LG']"><h1 align="center"><font color="navy"><u>VISA HOTEL INVOICE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='CR']"><h1 align="center"><font color="navy"><u>VISA CAR RENTAL INVOICE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='HC']"><h1 align="center"><font color="navy"><u>VISA HEALTH CARE INVOICE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='IG']"><h1 align="center"><font color="navy"><u>VISA GOVERNMENT INVOICE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='TS']"><h1 align="center"><font color="navy"><u>VISA TEMPORARY SUPPLIER INVOICE</u></font></h1></xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='MM']"><h1 align="center"><font color="navy"><u>VISA MISCELLANEOUS SUPPLIER INVOICE</u></font></h1></xsl:when>
			<xsl:otherwise><h1 align="center"><font color="navy"><u>VISA INVOICE</u></font></h1></xsl:otherwise>
		</xsl:choose>
	</xsl:otherwise>
</xsl:choose>
</head>

<body bgcolor="burlywood" text ="navy">

<!-- Invoice number, Message Type and Invoice Currency -->
<table border="0" cellpadding="3" cellspacing="2">
		<tr>
			<td><font color="blue">Card Number: </font>
			<xsl:value-of select="InvoiceSummary/ActualPayment/CardInfo/CardNum[0][../CardType/@stdValue='VS']" />
			</td>
			<td></td>
		</tr>
</table>
<table border="0" cellpadding="3" cellspacing="2">
	<tr>
		<td><font color="blue">Message Type</font></td>
		<td><font color="blue">Invoice Number</font></td>
		<td><font color="blue">Invoice Date/Time</font></td>
		<td><font color="blue">Currency</font></td>
	</tr>

	<xsl:for-each select="InvoiceHeader">

<!-- This following line substitutes an attribute and a code lookup
InvoiceType Field -->
	<tr>
		<xsl:apply-templates select="InvoiceType" />

<!-- Invoice number -->

		<td><xsl:value-of select="InvoiceNumber" /></td>
<!-- Invoice Date
This entry checks to see if the date has a value of 3 and enters that in
the field if it does
-->
	<xsl:apply-templates select="InvoiceDate" />

<!-- Lookup for Currency Code as above for InvoiceType -->
	<xsl:apply-templates select="Currency" />

	</tr>
</xsl:for-each>
</table>

<p />
<hr size="1"></hr>

<!-- Guest details block -->
<p>
	<table border="0" cellpadding="0" cellspacing="5" align="centre">
		<xsl:choose>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='AI']">
				<tr>
					<td><font color="blue">Passenger Name:</font></td>
					<td><xsl:value-of select="InvoiceHeader/Party[@stdValue='BY']/Contact/Name1" /></td>
<!-- Airline Specific Data -->
					<xsl:if test="InvoiceHeader/Ref[@stdValue='FLNO']"><td><font color="blue">Flight Number:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='FLNO']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='CARR']"><td><font color="blue">Carrier Code:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='CARR']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='LOC1']"><td><font color="blue">Origination City:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='LOC1']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='LOC2']"><td><font color="blue">Destination City:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='LOC2']" /></td></xsl:if>
				</tr>
				<tr>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='SRVC']"><td><font color="blue">Service Class:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='SRVC']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='CPNO']"><td><font color="blue">Coupon Number:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='CPNO']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='STOP']"><td><font color="blue">Stopover Indicator:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='STOP']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='FBC']"><td><font color="blue">Fare Basis Code:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='FBC']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='REFI']"><td><font color="blue">Refund Indicator:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='REFI']" /></td></xsl:if>
				</tr>
			</xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='LG']">
				<tr>
					<td><font color="blue">Guest Name:</font></td>
					<td><xsl:value-of select="InvoiceHeader/Party[@stdValue='BY']/Contact/Name1" /></td>
<!-- Hotel Specific Data -->
					<xsl:if test="InvoiceHeader/Ref[@stdValue='RSNO']"><td><font color="blue">Reservation number:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='RSNO']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='RMNO']"><td><font color="blue">Room number:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='RMNO']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='RMRT']"><td><font color="blue">Room rate:</font></td><td align="right"><xsl:for-each select="InvoiceHeader/Ref[@stdValue='RMRT'][0]" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td></xsl:if>
				</tr>
			</xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='CR']">
				<tr>
					<td><font color="blue">Renter:</font></td>
					<td><xsl:value-of select="InvoiceHeader/Party[@stdValue='BY']/Name/Name1" /></td>
<!-- Car Rental Specific Data -->
					<xsl:if test="InvoiceHeader/Ref[@stdValue='RSNO']"><td><font color="blue">Reservation Number:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='RSNO']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='LOC1']"><td><font color="blue">Rented From:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='LOC1']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='LOC2']"><td><font color="blue">Returned To:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='LOC2']" /></td></xsl:if>
				</tr>
				<tr>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='DCI']"><td><font color="blue">Checkin Reading:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='DCI']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='DCO']"><td><font color="blue">Checkout Reading:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='DCO']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='DDV']"><td><font color="blue">Distance Travelled:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='DDV']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='UOD']"><td><font color="blue">Unit of distance:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='UOD']" /></td></xsl:if>
				</tr>
				<tr>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='VREG']"><td><font color="blue">Vehicle Registration No:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='VREG']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='VT']"><td><font color="blue">Vehicle Type:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='VT']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='VGCH']"><td><font color="blue">Vehicle Group Charged:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='VGCH']" /></td></xsl:if>
					<xsl:if test="InvoiceHeader/Ref[@stdValue='OVD']"><td><font color="blue">Other Data:</font></td><td><xsl:value-of select="InvoiceHeader/Ref[@stdValue='OVD']" /></td></xsl:if>
				</tr>
			</xsl:when>
<!-- 			Other Sectors ???
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='HC']"> </xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='IG']"> </xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='TS']"> </xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='MM']"> </xsl:when>
-->
			<xsl:otherwise>
				<tr>
					<td><font color="blue">Invoicee:</font></td>
					<td><xsl:value-of select="InvoiceHeader/Party[@stdValue='BY']/Name/Name1" /></td>
				</tr>
			</xsl:otherwise>
		</xsl:choose>
	</table>
</p>
<hr size="1"></hr>
<!-- Date Information -->
<xsl:if test="InvoiceHeader/Ref[@stdValue='ADQ'][.='AI' || . ='CR' || . ='LG']">
<p>
<table border="1">
	<tr>
		<xsl:choose>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='AI']">
				<xsl:if test="InvoiceHeader/Date[@stdValue='STRT']"><th><font color="blue">Departure Date</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='STRT']"><th><font color="blue">Departure Time</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='END']"><th><font color="blue">Arrival Date</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='END']"><th><font color="blue">Arrival Time</font></th></xsl:if>
			</xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='LG']">
				<xsl:if test="InvoiceHeader/Date[@stdValue='STRT']"><th><font color="blue">Check In Date</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='STRT']"><th><font color="blue">Check In Time</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='END']"><th><font color="blue">Check Out Date</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='END']"><th><font color="blue">Check Out Time</font></th></xsl:if>
			</xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='CR']">
				<xsl:if test="InvoiceHeader/Date[@stdValue='STRT']"><th><font color="blue">Check Out Date</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='STRT']"><th><font color="blue">Check Out Time</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='END']"><th><font color="blue">Check In Date</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='END']"><th><font color="blue">Check In Time</font></th></xsl:if>
			</xsl:when>
<!-- 			Other Sectors do not have these dates ???
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='HC']"> </xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='IG']"> </xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='TS']"> </xsl:when>
			<xsl:when test="InvoiceHeader/Ref[@stdValue='ADQ'][.='MM']"> </xsl:when>
-->			<xsl:otherwise>
				<xsl:if test="InvoiceHeader/Date[@stdValue='STRT']"><th><font color="blue">Start Date</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='STRT']"><th><font color="blue">Start Time</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='END']"><th><font color="blue">End Date</font></th></xsl:if>
				<xsl:if test="InvoiceHeader/Date[@stdValue='END']"><th><font color="blue">End Time</font></th></xsl:if>
</xsl:otherwise>
		</xsl:choose>
	</tr>

	<xsl:for-each select="InvoiceHeader">
	<!--
	The following syntax <xsl:for-each select="Date[@stdValue='STRT']">
	allows the selection of date based on the value of the stdValue attribute.
	This is extremely useful and important
	-->
	<tr>
		<td><font size="-1"><xsl:for-each select="Date[@stdValue='STRT']"><xsl:eval>DateFormat(nodeTypedValue)</xsl:eval></xsl:for-each></font></td>
		<td><font size="-1"><xsl:for-each select="Date[@stdValue='STRT']"><xsl:eval>ShortTimeFormat(nodeTypedValue)</xsl:eval></xsl:for-each></font></td>
		<td><font size="-1"><xsl:for-each select="Date[@stdValue='END']"><xsl:eval>DateFormat(nodeTypedValue)</xsl:eval></xsl:for-each></font></td>
		<td><font size="-1"><xsl:for-each select="Date[@stdValue='END']"><xsl:eval>ShortTimeFormat(nodeTypedValue)</xsl:eval></xsl:for-each></font></td>
	</tr>

</xsl:for-each>
</table>
</p>
<hr size="1"></hr>
</xsl:if>

<!-- Supplier Details -->
<p>
<table border="1" cellpadding="0">
	<tr>
		<th><font color="blue">Supplier</font></th>
		<th><font color="blue">Address</font></th>
		<th><font color="blue">Country</font></th>
		<th><font color="blue">Tax Reg No</font></th>
		<th><font color="blue">Reg No</font></th>
	</tr>
	<tr><font size="-1">
	<xsl:for-each select="InvoiceHeader/Party[@stdValue= 'SU']">
		<td valign="top"><xsl:value-of select="Name/Name1" /><BR /><xsl:value-of select="Name/Name2" /></td>
		<td valign="top">
			<xsl:if test="Street/Street1"><xsl:value-of select="Street/Street1" /><BR /></xsl:if>
			<xsl:if test="PostalInfo/City"><xsl:value-of select="PostalInfo/City" /><BR /></xsl:if>
			<xsl:if test="PostalInfo/CountrySubEntity"><xsl:value-of select="PostalInfo/CountrySubEntity" /><BR /></xsl:if>
			<xsl:if test="PostalInfo/PostalCode"><xsl:value-of select="PostalInfo/PostalCode" /></xsl:if>
		</td>
		<td valign="top"><xsl:value-of select="PostalInfo/Country" /></td>
		<td valign="top"><xsl:value-of select="Ref[@stdValue='VA']" /></td>
		<td valign="top"><xsl:value-of select="Ref[@stdValue='XA']" /></td>
	</xsl:for-each>
	</font></tr>
</table>
</p>
<hr size="1"></hr>
<p>
<!-- Line item details -->
<table border="2" cellpadding="1" cellspacing="1" cellheight="2" frame="border" >
<xsl:for-each select="InvoiceDetails">
<xsl:if test="context()[0]">
<tr>
<xsl:if test="//InvoiceDetails/BaseItemDetail/LineItemNum">
	<th><font color="blue">Line No</font></th>
</xsl:if>
<xsl:if test="//InvoiceDetails/BaseItemDetail/PartNumDetail[@stdValue='CC']/PartNum">
	<th><font color="blue">Commodity Code</font></th>
</xsl:if>

<xsl:if test="//InvoiceDetails/BaseItemDetail/PartNumDetail[@stdValue='VP']/PartNum">
	<th><font color="blue">Product Code</font></th>
</xsl:if>
<th><font color="blue">Description</font></th>
<th><font color="blue">Qty</font></th>
<th><font color="blue">UOM</font></th>
<th><font color="blue">Cost</font></th>
<th><font color="blue">Sub-Total</font></th>
<th><font color="blue">Tax Rate(%)</font></th>
<xsl:if test="//InvoiceHeader/Ref[@stdValue='ADQ'][.='LG']">
	<th><font color="blue">Purchase Date/Time</font></th>
</xsl:if>
</tr>
</xsl:if>
<tr>
<xsl:choose>
	<xsl:when test="BaseItemDetail[./SubLineItemNum]">
		<xsl:if test="//InvoiceDetails/BaseItemDetail/LineItemNum">
			<td ></td>
		</xsl:if>
		<xsl:if test="//InvoiceDetails/BaseItemDetail/PartNumDetail[@stdValue='CC']/PartNum">
			<td ></td>
		</xsl:if>
 		<xsl:if test="//InvoiceDetails/BaseItemDetail/PartNumDetail[@stdValue='VP']/PartNum">
			<td ></td>
		</xsl:if>
		<td ></td>
		<td align="left" colspan="5">
			<font size="-1">
				<xsl:value-of select="Ref[@stdValue='LOC1']" />-><xsl:value-of select="Ref[@stdValue='LOC2']" /> <xsl:value-of select="Ref[@stdValue='CARR']" /><xsl:value-of select="Ref[@stdValue='FLNO']" /> <xsl:for-each select="Date[@stdValue='STRT']"><xsl:eval>DateFormat(nodeTypedValue)</xsl:eval> <xsl:eval>ShortTimeFormat(nodeTypedValue)</xsl:eval> </xsl:for-each> <xsl:value-of select="Ref[@stdValue='SRVC']" /> <xsl:apply-templates select="Ref[@stdValue='STOP']" /> <xsl:value-of select="Ref[@stdValue='REFI']" />
			</font>
		</td>
	</xsl:when>
	<xsl:otherwise>
		<xsl:if test="//InvoiceDetails/BaseItemDetail/LineItemNum">
			<td align="right"><font size="-1"><xsl:value-of select="BaseItemDetail/LineItemNum" /></font></td>
		</xsl:if>
		<xsl:if test="//InvoiceDetails/BaseItemDetail/PartNumDetail[@stdValue='CC']/PartNum">
			<td align="right"><font size="-1"><xsl:value-of select="BaseItemDetail/PartNumDetail[@stdValue='CC']/PartNum" /></font></td>
		</xsl:if>
		<xsl:if test="//InvoiceDetails/BaseItemDetail/PartNumDetail[@stdValue='VP']/PartNum">
			<td align="right"><font size="-1"><xsl:value-of select="BaseItemDetail/PartNumDetail[@stdValue='VP']/PartNum" /></font></td>
		</xsl:if>
		<td ><font size="-1"><xsl:value-of select="BaseItemDetail/PartNumDetail[@stdValue='VP']/PartDesc" /></font></td>
		<td align="right"><font size="-1"><xsl:for-each select="BaseItemDetail/Quantity/Qty" ><xsl:eval>QtyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></font></td>
		<td ><font size="-1"><xsl:value-of select="BaseItemDetail/Quantity/UnitOfMeasure/@stdValue" /></font></td>
		<td align="right"><font size="-1"><xsl:for-each select="UnitPrice" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></font></td>
		<td align="right"><font size="-1"><xsl:for-each select="LineItemSubtotal" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></font></td>
		<td align="right"><font size="-1"><xsl:for-each select="Tax[0]/TaxPercent" ><xsl:eval>PercentFormat(nodeTypedValue)</xsl:eval></xsl:for-each></font></td>
		<xsl:if test="//InvoiceHeader/Ref[@stdValue='ADQ'][.='LG']">
			<td nowrap=""><font size="-1"><xsl:for-each select="Date[@stdValue='STRT']"><xsl:eval>DateFormat(nodeTypedValue)</xsl:eval> <xsl:eval>TimeFormat(nodeTypedValue)</xsl:eval></xsl:for-each></font></td>
		</xsl:if>
	</xsl:otherwise>
</xsl:choose>
</tr>
</xsl:for-each>
</table>
</p>

<!-- Summary Details -->
<hr size="1" color="navy"></hr>
<h2><u>SUMMARY DETAILS</u></h2>

<!-- Payment details -->
<xsl:if test=" InvoiceSummary/ActualPayment">
<p>
<H3>PAYMENT SUMMARY DETAILS</H3>
<table border="1" cellpadding="3" cellspacing="2" frame="border">
<xsl:for-each select="InvoiceSummary/ActualPayment" order-by="-CardInfo/CardExpirationDate">
	<xsl:if test="context()[0]">
		<tr>
			<th><font color="blue">Payment<br/>Method</font></th>
			<th><font color="blue">Payment <br/>Date</font></th>
			<th><font color="blue">Amount<br/>Paid</font></th>
			<xsl:if test="../ActualPayment/PaymentAmount/ForeignCurrencyPayment/ForeignCurrencyAmt"><th><font color="blue">Foreign Current Amt</font></th><th><font color="blue">Foreign Currency Code</font></th></xsl:if>
			<th><font color="blue">Expires</font></th>
			<th><font color="blue">Card Used<br/>For Payment</font></th>
		</tr>
	</xsl:if>

	<tr>
		<xsl:choose>
			<xsl:when test="CardInfo/CardType/@stdValue"><xsl:apply-templates select=" CardInfo/CardType" /></xsl:when>
			<xsl:otherwise><xsl:apply-templates select="PaymentMean" /></xsl:otherwise>
		</xsl:choose>
		<td><xsl:for-each select="PaymentDate"><xsl:eval>DateFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td>
		<td align="right"><xsl:for-each select="PaymentAmount/LocalCurrencyAmt" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td>
		<xsl:choose>
			<xsl:when test="PaymentAmount/ForeignCurrencyPayment/ForeignCurrencyAmt">
				<td align="right"><xsl:for-each select="PaymentAmount/ForeignCurrencyPayment/ForeignCurrencyAmt" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td>
				<xsl:apply-templates select="PaymentAmount/ForeignCurrencyPayment/Currency" />
			</xsl:when>
			<xsl:otherwise>
					<xsl:if test="../ActualPayment/PaymentAmount/ForeignCurrencyPayment/ForeignCurrencyAmt"><td /><td /></xsl:if>
			</xsl:otherwise>
		</xsl:choose>
		<td><xsl:value-of select="CardInfo/CardExpirationDate" /></td>
		<td><xsl:value-of select="CardInfo/CardNum" /></td>
	</tr>
</xsl:for-each>
</table>
</p>
<hr size="1" />
</xsl:if>

<xsl:if test="InvoiceSummary/InvoiceTotals">
<p>
	<!-- Total Details -->
	<H3>TOTAL SUMMARY DETAILS</H3>
	<table border="1" cellpadding="3" cellspacing="2">
	<xsl:for-each select="InvoiceSummary/InvoiceTotals">
		<xsl:if test="context()[0]">
			<tr>
				<th><font color="blue">Total Net Amount</font></th>
				<th><font color="blue">Total Tax Amount </font></th>
				<th><font color="blue">Total Gross Amount </font></th>
			</tr>
		</xsl:if>
		<tr>
			<td align="right"><xsl:for-each select="NetValue" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td>
			<td align="right"><xsl:for-each select="TaxValue" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td>
			<td align="right"><xsl:for-each select="GrossValue" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td>
		</tr>
	</xsl:for-each>
	</table>
	</p>
	<hr size="1" />
</xsl:if>

<!-- Tax Details -->
<xsl:if test="InvoiceSummary/TaxSummary/Tax">
<p>
<H3>TAX SUMMARY DETAILS</H3>
<table border="1" cellpadding="3" cellspacing="2">
	<xsl:for-each select="InvoiceSummary/TaxSummary/Tax" order-by="TaxPercent">
		<xsl:if test="context()[0]">
			<tr>
				<th><font color="blue">Tax Rate(%)</font></th>
				<xsl:if test="../../TaxSummary/Tax/TaxCategory[@stdValue]">
					<th><font color="blue">Tax Category</font></th>
   				</xsl:if>
				<th><font color="blue">Total Net Amount</font></th>
				<th><font color="blue">Total Tax</font></th>
			</tr>
		</xsl:if>
		<tr>
			<td align="right"><xsl:for-each select="TaxPercent" ><xsl:eval>PercentFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td>
			<xsl:if test="../../TaxSummary/Tax/TaxCategory[@stdValue]">
				<xsl:apply-templates select="TaxCategory" />
			</xsl:if>
			<td align="right"><xsl:for-each select="TaxableAmount" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td>
			<td align="right"><xsl:for-each select="TaxAmount" ><xsl:eval>MoneyFormat(nodeTypedValue)</xsl:eval></xsl:for-each></td>
		</tr>
	</xsl:for-each>
</table>
</p>
</xsl:if>

</body>
</xsl:for-each>
</html>
<xsl:apply-templates />
</xsl:template>

<xsl:template match="InvoiceType">
	<xsl:choose>
		<xsl:when test="@stdValue[.='381']"><td>Credit Note</td></xsl:when>
		<xsl:when test="@stdValue[.='380']"><td>Invoice</td></xsl:when>
		<xsl:otherwise><td>Value not in list</td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="InvoiceStatus">
	<xsl:choose>
		<xsl:when test="@stdValue[.='9']"><td>Original</td></xsl:when>
		<xsl:when test="@stdValue[.='10']"><td>Copy</td></xsl:when>
		<xsl:when test="@stdValue[.='53']"><td>Test</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Invoice Status <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="InvoiceTreatment">
	<xsl:choose>
		<xsl:when test="@stdValue[.='P']"><td>Invoice printed and given to purchaser, and used for tax reclaim </td></xsl:when>
		<xsl:when test="@stdValue[.='EP']"><td>Printed, but printed invoice treated as supplemental invoice since electronic copy used for tax reclaim</td></xsl:when>
		<xsl:when test="@stdValue[.='E']"><td>Printed invoice suppressed since electronic master version used for tax reclaim</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Invoice Treatment <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="Currency">
	<xsl:choose>
		<xsl:when test="@stdValue[.='AED']"><td>Dirham</td></xsl:when>
		<xsl:when test="@stdValue[.='AFA']"><td>Afghani</td></xsl:when>
		<xsl:when test="@stdValue[.='ALL']"><td>Lek</td></xsl:when>
		<xsl:when test="@stdValue[.='AMD']"><td>Dram</td></xsl:when>
		<xsl:when test="@stdValue[.='ANG']"><td>Guilder</td></xsl:when>
		<xsl:when test="@stdValue[.='AOK']"><td>New Kwanza</td></xsl:when>
		<xsl:when test="@stdValue[.='ARP']"><td>Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='ATS']"><td>Schilling</td></xsl:when>
		<xsl:when test="@stdValue[.='AUD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='AWF']"><td>Florin</td></xsl:when>
		<xsl:when test="@stdValue[.='AZM']"><td>Manat</td></xsl:when>
		<xsl:when test="@stdValue[.='BAK']"><td>Convertible Mk</td></xsl:when>
		<xsl:when test="@stdValue[.='BBD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='BDT']"><td>Taka</td></xsl:when>
		<xsl:when test="@stdValue[.='BEF']"><td>Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='BGL']"><td>Lev</td></xsl:when>
		<xsl:when test="@stdValue[.='BHD']"><td>Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='BIF']"><td>Burundi Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='BMD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='BND']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='BOB']"><td>Boliviano</td></xsl:when>
		<xsl:when test="@stdValue[.='BRR']"><td>Brazilian Real</td></xsl:when>
		<xsl:when test="@stdValue[.='BSD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='BTR']"><td>Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='BWP']"><td>Pula</td></xsl:when>
		<xsl:when test="@stdValue[.='BYR']"><td>Ruble</td></xsl:when>
		<xsl:when test="@stdValue[.='BZD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='CAD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='CHF']"><td>Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='CLP']"><td>Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='CNY']"><td>Yuan Renminbi</td></xsl:when>
		<xsl:when test="@stdValue[.='COP']"><td>Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='CRC']"><td>Colon</td></xsl:when>
		<xsl:when test="@stdValue[.='CUP']"><td>Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='CVE']"><td>Escudo</td></xsl:when>
		<xsl:when test="@stdValue[.='CYP']"><td>Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='DEM']"><td>Deutsche Mark</td></xsl:when>
		<xsl:when test="@stdValue[.='DJF']"><td>Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='DKK']"><td>Krone</td></xsl:when>
		<xsl:when test="@stdValue[.='DOP']"><td>Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='DZD']"><td>Algerian Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='ECS']"><td>Sucre</td></xsl:when>
		<xsl:when test="@stdValue[.='EEK']"><td>Kroon</td></xsl:when>
		<xsl:when test="@stdValue[.='EGP']"><td>Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='ERN']"><td>Nakfa</td></xsl:when>
		<xsl:when test="@stdValue[.='ESP']"><td>Peseta</td></xsl:when>
		<xsl:when test="@stdValue[.='ETB']"><td>Birr</td></xsl:when>
		<xsl:when test="@stdValue[.='EUR']"><td>Euro</td></xsl:when>
		<xsl:when test="@stdValue[.='FIM']"><td>Markka</td></xsl:when>
		<xsl:when test="@stdValue[.='FJD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='FKP']"><td>Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='FRF']"><td>Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='GBP']"><td>Pound Sterling</td></xsl:when>
		<xsl:when test="@stdValue[.='GEL']"><td>Lari</td></xsl:when>
		<xsl:when test="@stdValue[.='GHC']"><td>Cedi</td></xsl:when>
		<xsl:when test="@stdValue[.='GIP']"><td>Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='GMD']"><td>Dalasi</td></xsl:when>
		<xsl:when test="@stdValue[.='GNF']"><td>Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='GRD']"><td>Drachma</td></xsl:when>
		<xsl:when test="@stdValue[.='GTQ']"><td>Quetzal</td></xsl:when>
		<xsl:when test="@stdValue[.='GYD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='HKD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='HNL']"><td>Lempira</td></xsl:when>
		<xsl:when test="@stdValue[.='HRK']"><td>Kuna</td></xsl:when>
		<xsl:when test="@stdValue[.='HTG']"><td>Gourde</td></xsl:when>
		<xsl:when test="@stdValue[.='HUF']"><td>Forint</td></xsl:when>
		<xsl:when test="@stdValue[.='IDR']"><td>Rupiah</td></xsl:when>
		<xsl:when test="@stdValue[.='IEP']"><td>Punt</td></xsl:when>
		<xsl:when test="@stdValue[.='ILS']"><td>Shekel</td></xsl:when>
		<xsl:when test="@stdValue[.='INR']"><td>Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='IQD']"><td>Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='IRR']"><td>Rial</td></xsl:when>
		<xsl:when test="@stdValue[.='ISK']"><td>Krona</td></xsl:when>
		<xsl:when test="@stdValue[.='ITL']"><td>Lira</td></xsl:when>
		<xsl:when test="@stdValue[.='JMD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='JOD']"><td>Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='JPY']"><td>Yen</td></xsl:when>
		<xsl:when test="@stdValue[.='KES']"><td>Shilling</td></xsl:when>
		<xsl:when test="@stdValue[.='KGS']"><td>Som</td></xsl:when>
		<xsl:when test="@stdValue[.='KHR']"><td>Riel</td></xsl:when>
		<xsl:when test="@stdValue[.='KMF']"><td>Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='KPW']"><td>Won</td></xsl:when>
		<xsl:when test="@stdValue[.='KRW']"><td>Won</td></xsl:when>
		<xsl:when test="@stdValue[.='KWD']"><td>Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='KYD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='KZT']"><td>Tenge</td></xsl:when>
		<xsl:when test="@stdValue[.='LAK']"><td>Kip</td></xsl:when>
		<xsl:when test="@stdValue[.='LBP']"><td>Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='LKR']"><td>Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='LRD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='LSL']"><td>Loti</td></xsl:when>
		<xsl:when test="@stdValue[.='LTL']"><td>Lita</td></xsl:when>
		<xsl:when test="@stdValue[.='LUF']"><td>Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='LVL']"><td>Lat</td></xsl:when>
		<xsl:when test="@stdValue[.='LYD']"><td>Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='MAD']"><td>Dirham</td></xsl:when>
		<xsl:when test="@stdValue[.='MDL']"><td>Leu</td></xsl:when>
		<xsl:when test="@stdValue[.='MGF']"><td>Malagasy Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='MKD']"><td>Denar</td></xsl:when>
		<xsl:when test="@stdValue[.='MMK']"><td>Kyat</td></xsl:when>
		<xsl:when test="@stdValue[.='MNT']"><td>Tugrik</td></xsl:when>
		<xsl:when test="@stdValue[.='MOP']"><td>Pataca</td></xsl:when>
		<xsl:when test="@stdValue[.='MRO']"><td>Ouguiya</td></xsl:when>
		<xsl:when test="@stdValue[.='MTL']"><td>Lira</td></xsl:when>
		<xsl:when test="@stdValue[.='MUR']"><td>Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='MVR']"><td>Rufiyaa</td></xsl:when>
		<xsl:when test="@stdValue[.='MWK']"><td>Kwacha</td></xsl:when>
		<xsl:when test="@stdValue[.='MXN']"><td>Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='MYR']"><td>Ringgit</td></xsl:when>
		<xsl:when test="@stdValue[.='MZM']"><td>Metical</td></xsl:when>
		<xsl:when test="@stdValue[.='NAD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='NGN']"><td>Naira</td></xsl:when>
		<xsl:when test="@stdValue[.='NIO']"><td>Cordoba Oro</td></xsl:when>
		<xsl:when test="@stdValue[.='NLG']"><td>Guilder</td></xsl:when>
		<xsl:when test="@stdValue[.='NOK']"><td>Krone</td></xsl:when>
		<xsl:when test="@stdValue[.='NPR']"><td>Nepalese Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='NZD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='OMR']"><td>Sul Rial</td></xsl:when>
		<xsl:when test="@stdValue[.='PAB']"><td>Balboa</td></xsl:when>
		<xsl:when test="@stdValue[.='PEN']"><td>Nuevo Sol</td></xsl:when>
		<xsl:when test="@stdValue[.='PGK']"><td>Kina</td></xsl:when>
		<xsl:when test="@stdValue[.='PHP']"><td>Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='PKR']"><td>Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='PLZ']"><td>Zloty</td></xsl:when>
		<xsl:when test="@stdValue[.='PTE']"><td>Escudo</td></xsl:when>
		<xsl:when test="@stdValue[.='PYG']"><td>Guarani</td></xsl:when>
		<xsl:when test="@stdValue[.='QAR']"><td>Rial</td></xsl:when>
		<xsl:when test="@stdValue[.='ROL']"><td>Leu</td></xsl:when>
		<xsl:when test="@stdValue[.='RUR']"><td>Ruble</td></xsl:when>
		<xsl:when test="@stdValue[.='RWF']"><td>Rwanda Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='SAR']"><td>Riyal</td></xsl:when>
		<xsl:when test="@stdValue[.='SBD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='SBL']"><td>Luigino</td></xsl:when>
		<xsl:when test="@stdValue[.='SCR']"><td>Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='SDD']"><td>Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='SEK']"><td>Krona</td></xsl:when>
		<xsl:when test="@stdValue[.='SGD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='SHP']"><td>Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='SIT']"><td>Tolar</td></xsl:when>
		<xsl:when test="@stdValue[.='SKK']"><td>Koruna</td></xsl:when>
		<xsl:when test="@stdValue[.='SLL']"><td>Leone</td></xsl:when>
		<xsl:when test="@stdValue[.='SOS']"><td>Shilling</td></xsl:when>
		<xsl:when test="@stdValue[.='SRG']"><td>Guilder</td></xsl:when>
		<xsl:when test="@stdValue[.='STD']"><td>Dobra</td></xsl:when>
		<xsl:when test="@stdValue[.='SVC']"><td>Colon</td></xsl:when>
		<xsl:when test="@stdValue[.='SYP']"><td>Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='SZL']"><td>Lilangeni</td></xsl:when>
		<xsl:when test="@stdValue[.='THB']"><td>Baht</td></xsl:when>
		<xsl:when test="@stdValue[.='TJR']"><td>Ruble</td></xsl:when>
		<xsl:when test="@stdValue[.='TMM']"><td>Manat</td></xsl:when>
		<xsl:when test="@stdValue[.='TND']"><td>Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='TOP']"><td>Pa'anga</td></xsl:when>
		<xsl:when test="@stdValue[.='TRL']"><td>Lira</td></xsl:when>
		<xsl:when test="@stdValue[.='TTD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='TWD']"><td>Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='TZS']"><td>Shilling</td></xsl:when>
		<xsl:when test="@stdValue[.='UAH']"><td>Hryvnia</td></xsl:when>
		<xsl:when test="@stdValue[.='UGX']"><td>Shilling</td></xsl:when>
		<xsl:when test="@stdValue[.='USD']"><td>U.S. Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='UYU']"><td>Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='UZS']"><td>Som</td></xsl:when>
		<xsl:when test="@stdValue[.='VEB']"><td>Bolivar</td></xsl:when>
		<xsl:when test="@stdValue[.='VND']"><td>Dong</td></xsl:when>
		<xsl:when test="@stdValue[.='VUV']"><td>Vatu</td></xsl:when>
		<xsl:when test="@stdValue[.='WST']"><td>Tala</td></xsl:when>
		<xsl:when test="@stdValue[.='XAF']"><td>Franc BEAC</td></xsl:when>
		<xsl:when test="@stdValue[.='XAG']"><td>Ounces</td></xsl:when>
		<xsl:when test="@stdValue[.='XAU']"><td>Ounces</td></xsl:when>
		<xsl:when test="@stdValue[.='XCD']"><td>E. Caribbean Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='XOF']"><td>CFA Franc BCEAO</td></xsl:when>
		<xsl:when test="@stdValue[.='XPF']"><td>CFP Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='XPT']"><td>Ounces</td></xsl:when>
		<xsl:when test="@stdValue[.='YER']"><td>Rial</td></xsl:when>
		<xsl:when test="@stdValue[.='ZAR']"><td>Rand</td></xsl:when>
		<xsl:when test="@stdValue[.='ZMK']"><td>Kwacha</td></xsl:when>
		<xsl:when test="@stdValue[.='ZRN']"><td>New Zaire</td></xsl:when>
		<xsl:when test="@stdValue[.='ZWD']"><td>Zimbabwe Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='004']"><td>Afghani</td></xsl:when>
		<xsl:when test="@stdValue[.='008']"><td>Lek</td></xsl:when>
		<xsl:when test="@stdValue[.='012']"><td>Algerian Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='020']"><td>Spanish Peseta EDP 724</td></xsl:when>
		<xsl:when test="@stdValue[.='024']"><td>New Kwanza</td></xsl:when>
		<xsl:when test="@stdValue[.='031']"><td>Azerbaijan Manat</td></xsl:when>
		<xsl:when test="@stdValue[.='032']"><td>Argentine Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='040']"><td>Austrian Schilling</td></xsl:when>
		<xsl:when test="@stdValue[.='044']"><td>Bahamian Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='048']"><td>Bahraini Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='050']"><td>Taka</td></xsl:when>
		<xsl:when test="@stdValue[.='051']"><td>Armenian Dram</td></xsl:when>
		<xsl:when test="@stdValue[.='052']"><td>Barbados Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='056']"><td>Belgian Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='060']"><td>Bermudian Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='064']"><td>Indian Rupee, INR 356</td></xsl:when>
		<xsl:when test="@stdValue[.='068']"><td>Boliviano</td></xsl:when>
		<xsl:when test="@stdValue[.='070']"><td>Bosnian Convertible Mark, BAM 977</td></xsl:when>
		<xsl:when test="@stdValue[.='072']"><td>Pula</td></xsl:when>
		<xsl:when test="@stdValue[.='076']"><td>Brazillian Real, BRL 986</td></xsl:when>
		<xsl:when test="@stdValue[.='084']"><td>Belize Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='096']"><td>Brunei Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='100']"><td>Lev</td></xsl:when>
		<xsl:when test="@stdValue[.='104']"><td>Kyat</td></xsl:when>
		<xsl:when test="@stdValue[.='108']"><td>Burundi Franc</td></xsl:when>                       
		<xsl:when test="@stdValue[.='112']"><td>Belarussian Ruble</td></xsl:when>
		<xsl:when test="@stdValue[.='116']"><td>Riel</td></xsl:when>
		<xsl:when test="@stdValue[.='124']"><td>Canadian Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='132']"><td>Escudo</td></xsl:when>
		<xsl:when test="@stdValue[.='136']"><td>Cayman Is. Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='144']"><td>Sri Lanka Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='152']"><td>Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='156']"><td>Yuan Renminbi</td></xsl:when>                       
		<xsl:when test="@stdValue[.='170']"><td>Colombian Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='174']"><td>Comoro Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='180']"><td>New Zaire</td></xsl:when>
		<xsl:when test="@stdValue[.='188']"><td>Costa Rican Colon</td></xsl:when>
		<xsl:when test="@stdValue[.='191']"><td>Croatian Kuna</td></xsl:when>
		<xsl:when test="@stdValue[.='192']"><td>Cuban Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='196']"><td>Cyprus Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='200']"><td>KORUNA</td></xsl:when>                              
		<xsl:when test="@stdValue[.='203']"><td>Czech Koruna</td></xsl:when>
		<xsl:when test="@stdValue[.='208']"><td>Danish Krone</td></xsl:when>
		<xsl:when test="@stdValue[.='214']"><td>Dominican Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='218']"><td>Sucre</td></xsl:when>
		<xsl:when test="@stdValue[.='222']"><td>El Salvador Colon</td></xsl:when>
		<xsl:when test="@stdValue[.='226']"><td>CFA Franc BEAC, XAF 950</td></xsl:when>
		<xsl:when test="@stdValue[.='230']"><td>Ethiopian Birr</td></xsl:when>
		<xsl:when test="@stdValue[.='232']"><td>Eritrean Nakfa</td></xsl:when>
		<xsl:when test="@stdValue[.='233']"><td>Kroon</td></xsl:when>
		<xsl:when test="@stdValue[.='238']"><td>Falkland Is. Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='242']"><td>Fiji Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='246']"><td>Markka</td></xsl:when>
		<xsl:when test="@stdValue[.='250']"><td>French Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='262']"><td>Djibouti Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='268']"><td>Georgian Lari, GEL 981</td></xsl:when>
		<xsl:when test="@stdValue[.='270']"><td>Dalasi</td></xsl:when>
		<xsl:when test="@stdValue[.='280']"><td>Deutsche Mark</td></xsl:when>
		<xsl:when test="@stdValue[.='288']"><td>Cedi</td></xsl:when>
		<xsl:when test="@stdValue[.='292']"><td>Gibraltar Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='300']"><td>Drachma</td></xsl:when>
		<xsl:when test="@stdValue[.='320']"><td>Quetzal</td></xsl:when>
		<xsl:when test="@stdValue[.='324']"><td>Guinea Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='328']"><td>Guyana Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='332']"><td>Gourde</td></xsl:when>
		<xsl:when test="@stdValue[.='340']"><td>Lempira</td></xsl:when>
		<xsl:when test="@stdValue[.='344']"><td>Hong Kong Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='348']"><td>Forint</td></xsl:when>
		<xsl:when test="@stdValue[.='352']"><td>ICELAND KRONA</td></xsl:when>
		<xsl:when test="@stdValue[.='356']"><td>Indian Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='36 ']"><td>Australian Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='360']"><td>Rupiah</td></xsl:when>
		<xsl:when test="@stdValue[.='364']"><td>Iranian Rial</td></xsl:when>
		<xsl:when test="@stdValue[.='365']"><td>Iranian Airline Rate</td></xsl:when>
		<xsl:when test="@stdValue[.='368']"><td>Iraqi Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='372']"><td>Irish Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='376']"><td>Shekel</td></xsl:when>
		<xsl:when test="@stdValue[.='380']"><td>Italian Lira</td></xsl:when>
		<xsl:when test="@stdValue[.='388']"><td>Jamaican Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='392']"><td>Yen</td></xsl:when>
		<xsl:when test="@stdValue[.='398']"><td>Tenge</td></xsl:when>
		<xsl:when test="@stdValue[.='400']"><td>Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='404']"><td>Kenyan Shilling</td></xsl:when>
		<xsl:when test="@stdValue[.='408']"><td>Won</td></xsl:when>
		<xsl:when test="@stdValue[.='410']"><td>Won</td></xsl:when>
		<xsl:when test="@stdValue[.='414']"><td>Kuwaiti Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='417']"><td>Som</td></xsl:when>
		<xsl:when test="@stdValue[.='418']"><td>KIP</td></xsl:when>
		<xsl:when test="@stdValue[.='422']"><td>Lebanese Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='426']"><td>Rand, ZAR 710</td></xsl:when>
		<xsl:when test="@stdValue[.='428']"><td>Latvian Lats</td></xsl:when>
		<xsl:when test="@stdValue[.='430']"><td>Liberian Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='434']"><td>Libyan Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='440']"><td>Lithuanian Litas</td></xsl:when>
		<xsl:when test="@stdValue[.='442']"><td>Luxembourg Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='446']"><td>Pataca</td></xsl:when>
		<xsl:when test="@stdValue[.='450']"><td>Malagasy Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='454']"><td>Kwacha</td></xsl:when>
		<xsl:when test="@stdValue[.='458']"><td>Malaysian Ringgit</td></xsl:when>
		<xsl:when test="@stdValue[.='462']"><td>Rufiyaa</td></xsl:when>
		<xsl:when test="@stdValue[.='470']"><td>Maltese Lira</td></xsl:when>
		<xsl:when test="@stdValue[.='478']"><td>Ouguiya</td></xsl:when>
		<xsl:when test="@stdValue[.='480']"><td>Mauritius Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='484']"><td>Mexican Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='496']"><td>Tugrik</td></xsl:when>
		<xsl:when test="@stdValue[.='498']"><td>Moldovan Leu</td></xsl:when>
		<xsl:when test="@stdValue[.='504']"><td>Moroccan Dirham</td></xsl:when>
		<xsl:when test="@stdValue[.='508']"><td>Metical</td></xsl:when>
		<xsl:when test="@stdValue[.='512']"><td>Rial Omani</td></xsl:when>
		<xsl:when test="@stdValue[.='516']"><td>Namibia Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='524']"><td>Nepalese Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='528']"><td>Netherlands Guilder</td></xsl:when>
		<xsl:when test="@stdValue[.='532']"><td>Nether. Antillian Guilder</td></xsl:when>
		<xsl:when test="@stdValue[.='533']"><td>Aruban Guilder</td></xsl:when>
		<xsl:when test="@stdValue[.='548']"><td>Vatu</td></xsl:when>
		<xsl:when test="@stdValue[.='554']"><td>New Zealand Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='558']"><td>Cordoba Oro</td></xsl:when>
		<xsl:when test="@stdValue[.='566']"><td>Naira</td></xsl:when>
		<xsl:when test="@stdValue[.='578']"><td>Norwegian Krone</td></xsl:when>
		<xsl:when test="@stdValue[.='586']"><td>Pakistan Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='590']"><td>Balboa</td></xsl:when>
		<xsl:when test="@stdValue[.='598']"><td>Kina</td></xsl:when>
		<xsl:when test="@stdValue[.='600']"><td>Guarani</td></xsl:when>
		<xsl:when test="@stdValue[.='604']"><td>Nuevo Sol</td></xsl:when>
		<xsl:when test="@stdValue[.='608']"><td>Philippine Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='616']"><td>Polish New Zloty, PLN 985</td></xsl:when>
		<xsl:when test="@stdValue[.='620']"><td>Portuguese Escudo</td></xsl:when>
		<xsl:when test="@stdValue[.='624']"><td>Guinea-Bissau Peso</td></xsl:when>
		<xsl:when test="@stdValue[.='626']"><td>Timor Escudo</td></xsl:when>
		<xsl:when test="@stdValue[.='634']"><td>Qatari Rial</td></xsl:when>
		<xsl:when test="@stdValue[.='642']"><td>Leu</td></xsl:when>
		<xsl:when test="@stdValue[.='643']"><td>Russian Ruble</td></xsl:when>
		<xsl:when test="@stdValue[.='646']"><td>Rwanda Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='654']"><td>St. Helena Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='678']"><td>Dobra</td></xsl:when>
		<xsl:when test="@stdValue[.='682']"><td>Saudi Riyal</td></xsl:when>
		<xsl:when test="@stdValue[.='690']"><td>Seychelles Rupee</td></xsl:when>
		<xsl:when test="@stdValue[.='694']"><td>Leone</td></xsl:when>
		<xsl:when test="@stdValue[.='702']"><td>Singapore Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='703']"><td>Slovak Koruna</td></xsl:when>
		<xsl:when test="@stdValue[.='704']"><td>Dong</td></xsl:when>
		<xsl:when test="@stdValue[.='705']"><td>Tolar</td></xsl:when>
		<xsl:when test="@stdValue[.='706']"><td>Somali Shilling</td></xsl:when>
		<xsl:when test="@stdValue[.='710']"><td>Africa Rand</td></xsl:when>
		<xsl:when test="@stdValue[.='716']"><td>Zimbabwe Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='724']"><td>Spanish Peseta</td></xsl:when>
		<xsl:when test="@stdValue[.='736']"><td>Sudanese Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='737']"><td>Sudan Airline Rate</td></xsl:when>
		<xsl:when test="@stdValue[.='740']"><td>Surinam Guilder</td></xsl:when>
		<xsl:when test="@stdValue[.='748']"><td>Lilangeni</td></xsl:when>
		<xsl:when test="@stdValue[.='752']"><td>Swedish Krona</td></xsl:when>
		<xsl:when test="@stdValue[.='756']"><td>Swiss Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='760']"><td>Syrian Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='762']"><td>Tajik Ruble</td></xsl:when>
		<xsl:when test="@stdValue[.='764']"><td>Thailand Baht</td></xsl:when>
		<xsl:when test="@stdValue[.='776']"><td>Pa'anga</td></xsl:when>
		<xsl:when test="@stdValue[.='780']"><td>Trinidad and Tobago Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='784']"><td>Dirham</td></xsl:when>
		<xsl:when test="@stdValue[.='788']"><td>Tunisian Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='792']"><td>Turkish Lira</td></xsl:when>
		<xsl:when test="@stdValue[.='795']"><td>Manat</td></xsl:when>
		<xsl:when test="@stdValue[.='800']"><td>Uganda Shilling</td></xsl:when>
		<xsl:when test="@stdValue[.='804']"><td>Ukranian Hryvnia, UAH 980</td></xsl:when>
		<xsl:when test="@stdValue[.='807']"><td>Denar</td></xsl:when>
		<xsl:when test="@stdValue[.='810']"><td>Russian Ruble</td></xsl:when>
		<xsl:when test="@stdValue[.='818']"><td>Egyptian Pound</td></xsl:when>
		<xsl:when test="@stdValue[.='826']"><td>Pound Sterling</td></xsl:when>
		<xsl:when test="@stdValue[.='834']"><td>Tanzanian Shilling</td></xsl:when>
		<xsl:when test="@stdValue[.='840']"><td>U.S. Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='858']"><td>Uruguayo</td></xsl:when>
		<xsl:when test="@stdValue[.='860']"><td>Uzbekistan Sum</td></xsl:when>
		<xsl:when test="@stdValue[.='862']"><td>Bolivar</td></xsl:when>
		<xsl:when test="@stdValue[.='882']"><td>Tala</td></xsl:when>
		<xsl:when test="@stdValue[.='886']"><td>Yemeni Rial</td></xsl:when>
		<xsl:when test="@stdValue[.='891']"><td>Yugoslavian New Dinar</td></xsl:when>
		<xsl:when test="@stdValue[.='894']"><td>Zambian Kwacha</td></xsl:when>
		<xsl:when test="@stdValue[.='090']"><td>Solomon Is. Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='901']"><td>New Taiwan Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='950']"><td>CFA Franc BEAC</td></xsl:when>                         
		<xsl:when test="@stdValue[.='951']"><td>E. Caribbean Dollar</td></xsl:when>
		<xsl:when test="@stdValue[.='952']"><td>CFA Franc BCEAO</td></xsl:when>
		<xsl:when test="@stdValue[.='953']"><td>CFP Franc</td></xsl:when>
		<xsl:when test="@stdValue[.='977']"><td>Herzegovina Bosnian Convertible Mar</td></xsl:when>
		<xsl:when test="@stdValue[.='978']"><td>euro</td></xsl:when>
		<xsl:when test="@stdValue[.='980']"><td>UKRAINIAN HRYVNIA</td></xsl:when>
		<xsl:when test="@stdValue[.='981']"><td>Georgian Lari</td></xsl:when>
		<xsl:when test="@stdValue[.='985']"><td>Polish New Zloty</td></xsl:when>
		<xsl:when test="@stdValue[.='986']"><td>Brazilian Real</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Currency <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="Country">
	<xsl:choose>
		<xsl:when test=".[.='AD']"><td valign="top">Andorra</td></xsl:when>
		<xsl:when test=".[.='AE']"><td valign="top">United Arab Emirates</td></xsl:when>
		<xsl:when test=".[.='AF']"><td valign="top">Afghanistan</td></xsl:when>
		<xsl:when test=".[.='AG']"><td valign="top">Antigua</td></xsl:when>
		<xsl:when test=".[.='AL']"><td valign="top">Albania</td></xsl:when>
		<xsl:when test=".[.='AM']"><td valign="top">Armenia</td></xsl:when>
		<xsl:when test=".[.='AN']"><td valign="top">Netherlands Antilles</td></xsl:when>
		<xsl:when test=".[.='AO']"><td valign="top">Angola</td></xsl:when>
		<xsl:when test=".[.='AQ']"><td valign="top">Antarctica</td></xsl:when>
		<xsl:when test=".[.='AR']"><td valign="top">Argentina</td></xsl:when>
		<xsl:when test=".[.='AS']"><td valign="top">American Samoa</td></xsl:when>
		<xsl:when test=".[.='AT']"><td valign="top">Austria</td></xsl:when>
		<xsl:when test=".[.='AU']"><td valign="top">Australia</td></xsl:when>
		<xsl:when test=".[.='AZ']"><td valign="top">Azerbaijan</td></xsl:when>
		<xsl:when test=".[.='BA']"><td valign="top">Bosnia-Herzegovina</td></xsl:when>
		<xsl:when test=".[.='BB']"><td valign="top">Barbados</td></xsl:when>
		<xsl:when test=".[.='BD']"><td valign="top">Bangladesh</td></xsl:when>
		<xsl:when test=".[.='BE']"><td valign="top">Belgium</td></xsl:when>
		<xsl:when test=".[.='BG']"><td valign="top">Bulgaria</td></xsl:when>
		<xsl:when test=".[.='BH']"><td valign="top">Bahrain</td></xsl:when>
		<xsl:when test=".[.='BI']"><td valign="top">Burundi</td></xsl:when>
		<xsl:when test=".[.='BJ']"><td valign="top">Benin</td></xsl:when>
		<xsl:when test=".[.='BM']"><td valign="top">Bermuda</td></xsl:when>
		<xsl:when test=".[.='BN']"><td valign="top">Brunei</td></xsl:when>
		<xsl:when test=".[.='BO']"><td valign="top">Bolivia</td></xsl:when>
		<xsl:when test=".[.='BR']"><td valign="top">Brazil</td></xsl:when>
		<xsl:when test=".[.='BS']"><td valign="top">Bahamas</td></xsl:when>
		<xsl:when test=".[.='BT']"><td valign="top">Bhutan</td></xsl:when>
		<xsl:when test=".[.='BU']"><td valign="top">Burma</td></xsl:when>
		<xsl:when test=".[.='BV']"><td valign="top">Bouvet Island</td></xsl:when>
		<xsl:when test=".[.='BW']"><td valign="top">Botswana</td></xsl:when>
		<xsl:when test=".[.='BY']"><td valign="top">Byelorussian Ssr (Bielorussia)</td></xsl:when>
		<xsl:when test=".[.='BZ']"><td valign="top">Belize</td></xsl:when>
		<xsl:when test=".[.='CA']"><td valign="top">Canada</td></xsl:when>
		<xsl:when test=".[.='CC']"><td valign="top">Cocos Islands</td></xsl:when>
		<xsl:when test=".[.='CF']"><td valign="top">Central African Republic</td></xsl:when>
		<xsl:when test=".[.='CG']"><td valign="top">Congo</td></xsl:when>
		<xsl:when test=".[.='CH']"><td valign="top">Switzerland</td></xsl:when>
		<xsl:when test=".[.='CI']"><td valign="top">Ivory Coast</td></xsl:when>
		<xsl:when test=".[.='CK']"><td valign="top">Cook Islands</td></xsl:when>
		<xsl:when test=".[.='CL']"><td valign="top">Chile</td></xsl:when>
		<xsl:when test=".[.='CM']"><td valign="top">United Republic of Cameroon</td></xsl:when>
		<xsl:when test=".[.='CN']"><td valign="top">China</td></xsl:when>
		<xsl:when test=".[.='CO']"><td valign="top">Columbia</td></xsl:when>
		<xsl:when test=".[.='CR']"><td valign="top">Costa Rica</td></xsl:when>
		<xsl:when test=".[.='CS']"><td valign="top">Czechoslovakia</td></xsl:when>
		<xsl:when test=".[.='CT']"><td valign="top">Canton and Enderbury Islands</td></xsl:when>
		<xsl:when test=".[.='CU']"><td valign="top">Cuba</td></xsl:when>
		<xsl:when test=".[.='CV']"><td valign="top">Cape Verde</td></xsl:when>
		<xsl:when test=".[.='CX']"><td valign="top">Christmas Island</td></xsl:when>
		<xsl:when test=".[.='CY']"><td valign="top">Cyprus</td></xsl:when>
		<xsl:when test=".[.='CZ']"><td valign="top">Czech</td></xsl:when>
		<xsl:when test=".[.='DE']"><td valign="top">Federal Republic of Germany</td></xsl:when>
		<xsl:when test=".[.='DJ']"><td valign="top">Djibouti</td></xsl:when>
		<xsl:when test=".[.='DK']"><td valign="top">Denmark</td></xsl:when>
		<xsl:when test=".[.='DM']"><td valign="top">Dominica</td></xsl:when>
		<xsl:when test=".[.='DO']"><td valign="top">Dominican Republic</td></xsl:when>
		<xsl:when test=".[.='DZ']"><td valign="top">Algeria</td></xsl:when>
		<xsl:when test=".[.='EC']"><td valign="top">Ecuador</td></xsl:when>
		<xsl:when test=".[.='EG']"><td valign="top">Egypt</td></xsl:when>
		<xsl:when test=".[.='EH']"><td valign="top">Western Sahara</td></xsl:when>
		<xsl:when test=".[.='ES']"><td valign="top">Spain</td></xsl:when>
		<xsl:when test=".[.='ET']"><td valign="top">Ethiopia</td></xsl:when>
		<xsl:when test=".[.='FI']"><td valign="top">Finland</td></xsl:when>
		<xsl:when test=".[.='FJ']"><td valign="top">Fiji</td></xsl:when>
		<xsl:when test=".[.='FK']"><td valign="top">Falkland Islands</td></xsl:when>
		<xsl:when test=".[.='FO']"><td valign="top">Faeroe Islands</td></xsl:when>
		<xsl:when test=".[.='FR']"><td valign="top">France</td></xsl:when>
		<xsl:when test=".[.='GA']"><td valign="top">Gabon</td></xsl:when>
		<xsl:when test=".[.='GB']"><td valign="top">United Kingdom</td></xsl:when>
		<xsl:when test=".[.='GD']"><td valign="top">Grenada</td></xsl:when>
		<xsl:when test=".[.='GF']"><td valign="top">French Guiana</td></xsl:when>
		<xsl:when test=".[.='GG']"><td valign="top">Georgia</td></xsl:when>
		<xsl:when test=".[.='GH']"><td valign="top">Ghana</td></xsl:when>
		<xsl:when test=".[.='GI']"><td valign="top">Gibraltar</td></xsl:when>
		<xsl:when test=".[.='GL']"><td valign="top">Greenland</td></xsl:when>
		<xsl:when test=".[.='GM']"><td valign="top">Gambia</td></xsl:when>
		<xsl:when test=".[.='GN']"><td valign="top">Guinea</td></xsl:when>
		<xsl:when test=".[.='GP']"><td valign="top">Guadeloupe</td></xsl:when>
		<xsl:when test=".[.='GQ']"><td valign="top">Equatorial Guinea</td></xsl:when>
		<xsl:when test=".[.='GR']"><td valign="top">Greece</td></xsl:when>
		<xsl:when test=".[.='GT']"><td valign="top">Guatemala</td></xsl:when>
		<xsl:when test=".[.='GU']"><td valign="top">Guam</td></xsl:when>
		<xsl:when test=".[.='GW']"><td valign="top">Guinea-Bisseu</td></xsl:when>
		<xsl:when test=".[.='GY']"><td valign="top">Guyana</td></xsl:when>
		<xsl:when test=".[.='HK']"><td valign="top">Hong Kong</td></xsl:when>
		<xsl:when test=".[.='HM']"><td valign="top">Heard and Mc Donald Islands</td></xsl:when>
		<xsl:when test=".[.='HN']"><td valign="top">Honduras</td></xsl:when>
		<xsl:when test=".[.='HR']"><td valign="top">Croatia</td></xsl:when>
		<xsl:when test=".[.='HT']"><td valign="top">Haiti</td></xsl:when>
		<xsl:when test=".[.='HU']"><td valign="top">Hungary</td></xsl:when>
		<xsl:when test=".[.='HV']"><td valign="top">Upper Volta</td></xsl:when>
		<xsl:when test=".[.='ID']"><td valign="top">Indonesia</td></xsl:when>
		<xsl:when test=".[.='IE']"><td valign="top">Ireland</td></xsl:when>
		<xsl:when test=".[.='IL']"><td valign="top">Israel</td></xsl:when>
		<xsl:when test=".[.='IN']"><td valign="top">India</td></xsl:when>
		<xsl:when test=".[.='IO']"><td valign="top">British Indian Ocean Territory</td></xsl:when>
		<xsl:when test=".[.='IQ']"><td valign="top">Iraq</td></xsl:when>
		<xsl:when test=".[.='IR']"><td valign="top">Iran</td></xsl:when>
		<xsl:when test=".[.='IS']"><td valign="top">Iceland</td></xsl:when>
		<xsl:when test=".[.='IT']"><td valign="top">Italy</td></xsl:when>
		<xsl:when test=".[.='JM']"><td valign="top">Jamaica</td></xsl:when>
		<xsl:when test=".[.='JO']"><td valign="top">Jordan</td></xsl:when>
		<xsl:when test=".[.='JP']"><td valign="top">Japan</td></xsl:when>
		<xsl:when test=".[.='JT']"><td valign="top">Johnston Island</td></xsl:when>
		<xsl:when test=".[.='KE']"><td valign="top">Kenya</td></xsl:when>
		<xsl:when test=".[.='KG']"><td valign="top">Kyrgyzstan (Kirgistan)</td></xsl:when>
		<xsl:when test=".[.='KH']"><td valign="top">Democratic Kampuchea</td></xsl:when>
		<xsl:when test=".[.='KI']"><td valign="top">Kiribati</td></xsl:when>
		<xsl:when test=".[.='KK']"><td valign="top">Kazakhstan</td></xsl:when>
		<xsl:when test=".[.='KM']"><td valign="top">Comoros</td></xsl:when>
		<xsl:when test=".[.='KN']"><td valign="top">St. Kitts Nevis Anguilla</td></xsl:when>
		<xsl:when test=".[.='KP']"><td valign="top">Democratic People's Republic of Korea</td></xsl:when>
		<xsl:when test=".[.='KR']"><td valign="top">Republic of Korea</td></xsl:when>
		<xsl:when test=".[.='KW']"><td valign="top">Kuwait</td></xsl:when>
		<xsl:when test=".[.='KY']"><td valign="top">Cayman Islands</td></xsl:when>
		<xsl:when test=".[.='LA']"><td valign="top">Lao People's Democratic Republic</td></xsl:when>
		<xsl:when test=".[.='LB']"><td valign="top">Lebanon</td></xsl:when>
		<xsl:when test=".[.='LC']"><td valign="top">Saint Lucia</td></xsl:when>
		<xsl:when test=".[.='LI']"><td valign="top">Liechtenstein</td></xsl:when>
		<xsl:when test=".[.='LK']"><td valign="top">Sri Lanka</td></xsl:when>
		<xsl:when test=".[.='LR']"><td valign="top">Liberia</td></xsl:when>
		<xsl:when test=".[.='LS']"><td valign="top">Lesotho</td></xsl:when>
		<xsl:when test=".[.='LT']"><td valign="top">Lithuania</td></xsl:when>
		<xsl:when test=".[.='LU']"><td valign="top">Luxembourg</td></xsl:when>
		<xsl:when test=".[.='LV']"><td valign="top">Latvia</td></xsl:when>
		<xsl:when test=".[.='LY']"><td valign="top">Libyan Arab Jamahiriya</td></xsl:when>
		<xsl:when test=".[.='MA']"><td valign="top">Morrocco</td></xsl:when>
		<xsl:when test=".[.='MC']"><td valign="top">Monaco</td></xsl:when>
		<xsl:when test=".[.='MD']"><td valign="top">Moldova</td></xsl:when>
		<xsl:when test=".[.='MG']"><td valign="top">Madagascar</td></xsl:when>
		<xsl:when test=".[.='MI']"><td valign="top">Midway Islands</td></xsl:when>
		<xsl:when test=".[.='ML']"><td valign="top">Mali</td></xsl:when>
		<xsl:when test=".[.='MN']"><td valign="top">Mongolia</td></xsl:when>
		<xsl:when test=".[.='MO']"><td valign="top">Macau</td></xsl:when>
		<xsl:when test=".[.='MQ']"><td valign="top">Martinique</td></xsl:when>
		<xsl:when test=".[.='MR']"><td valign="top">Mauritania</td></xsl:when>
		<xsl:when test=".[.='MS']"><td valign="top">Montserrat</td></xsl:when>
		<xsl:when test=".[.='MT']"><td valign="top">Malta</td></xsl:when>
		<xsl:when test=".[.='MU']"><td valign="top">Mauritius</td></xsl:when>
		<xsl:when test=".[.='MV']"><td valign="top">Maldives</td></xsl:when>
		<xsl:when test=".[.='MW']"><td valign="top">Malawi</td></xsl:when>
		<xsl:when test=".[.='MX']"><td valign="top">Mexico</td></xsl:when>
		<xsl:when test=".[.='MY']"><td valign="top">Malasia</td></xsl:when>
		<xsl:when test=".[.='MZ']"><td valign="top">Mozambique</td></xsl:when>
		<xsl:when test=".[.='NA']"><td valign="top">Namibia</td></xsl:when>
		<xsl:when test=".[.='NC']"><td valign="top">New Calidonia</td></xsl:when>
		<xsl:when test=".[.='NE']"><td valign="top">Niger</td></xsl:when>
		<xsl:when test=".[.='NF']"><td valign="top">Norfolk Island</td></xsl:when>
		<xsl:when test=".[.='NG']"><td valign="top">Nigeria</td></xsl:when>
		<xsl:when test=".[.='NI']"><td valign="top">Nicaragua</td></xsl:when>
		<xsl:when test=".[.='NL']"><td valign="top">Netherlands</td></xsl:when>
		<xsl:when test=".[.='NO']"><td valign="top">Norway</td></xsl:when>
		<xsl:when test=".[.='NP']"><td valign="top">Napal</td></xsl:when>
		<xsl:when test=".[.='NQ']"><td valign="top">Dronning Maud Land</td></xsl:when>
		<xsl:when test=".[.='NR']"><td valign="top">Nauru</td></xsl:when>
		<xsl:when test=".[.='NT']"><td valign="top">Neutral Zone</td></xsl:when>
		<xsl:when test=".[.='NU']"><td valign="top">Niue</td></xsl:when>
		<xsl:when test=".[.='NZ']"><td valign="top">New Zealand</td></xsl:when>
		<xsl:when test=".[.='OM']"><td valign="top">Oman</td></xsl:when>
		<xsl:when test=".[.='PA']"><td valign="top">Panama</td></xsl:when>
		<xsl:when test=".[.='PC']"><td valign="top">Pacific Islands</td></xsl:when>
		<xsl:when test=".[.='PE']"><td valign="top">Peru</td></xsl:when>
		<xsl:when test=".[.='PF']"><td valign="top">French Polynesia</td></xsl:when>
		<xsl:when test=".[.='PG']"><td valign="top">Papua New Guinea</td></xsl:when>
		<xsl:when test=".[.='PH']"><td valign="top">Phillipines</td></xsl:when>
		<xsl:when test=".[.='PK']"><td valign="top">Pakistan</td></xsl:when>
		<xsl:when test=".[.='PL']"><td valign="top">Poland</td></xsl:when>
		<xsl:when test=".[.='PM']"><td valign="top">St. Pierre and Miquelon</td></xsl:when>
		<xsl:when test=".[.='PN']"><td valign="top">Pitcairn Island</td></xsl:when>
		<xsl:when test=".[.='PR']"><td valign="top">Puerto Rico</td></xsl:when>
		<xsl:when test=".[.='PT']"><td valign="top">Portugal</td></xsl:when>
		<xsl:when test=".[.='PU']"><td valign="top">United States Miscellaneous Pacific Islands</td></xsl:when>
		<xsl:when test=".[.='PY']"><td valign="top">Paraguay</td></xsl:when>
		<xsl:when test=".[.='QA']"><td valign="top">Qatar</td></xsl:when>
		<xsl:when test=".[.='RE']"><td valign="top">Reunion</td></xsl:when>
		<xsl:when test=".[.='RO']"><td valign="top">Romania</td></xsl:when>
		<xsl:when test=".[.='RU']"><td valign="top">Russia</td></xsl:when>
		<xsl:when test=".[.='RW']"><td valign="top">Rwanda</td></xsl:when>
		<xsl:when test=".[.='SA']"><td valign="top">Saudi Arabia</td></xsl:when>
		<xsl:when test=".[.='SB']"><td valign="top">Solomon Islands</td></xsl:when>
		<xsl:when test=".[.='SC']"><td valign="top">Seychelles</td></xsl:when>
		<xsl:when test=".[.='SD']"><td valign="top">Sudan</td></xsl:when>
		<xsl:when test=".[.='SE']"><td valign="top">Sweden</td></xsl:when>
		<xsl:when test=".[.='SG']"><td valign="top">Singapore</td></xsl:when>
		<xsl:when test=".[.='SH']"><td valign="top">St. Helena</td></xsl:when>
		<xsl:when test=".[.='SI']"><td valign="top">Slovenia</td></xsl:when>
		<xsl:when test=".[.='SJ']"><td valign="top">Svalbard and Jan Mayen Islands</td></xsl:when>
		<xsl:when test=".[.='SL']"><td valign="top">Sierra Leone</td></xsl:when>
		<xsl:when test=".[.='SM']"><td valign="top">San Marino</td></xsl:when>
		<xsl:when test=".[.='SN']"><td valign="top">Senegal</td></xsl:when>
		<xsl:when test=".[.='SO']"><td valign="top">Somalia</td></xsl:when>
		<xsl:when test=".[.='SQ']"><td valign="top">Slovakia</td></xsl:when>
		<xsl:when test=".[.='SR']"><td valign="top">Suriname</td></xsl:when>
		<xsl:when test=".[.='ST']"><td valign="top">Sao Tome and Principe</td></xsl:when>
		<xsl:when test=".[.='SU']"><td valign="top">USSR</td></xsl:when>
		<xsl:when test=".[.='SV']"><td valign="top">El Salvador</td></xsl:when>
		<xsl:when test=".[.='SY']"><td valign="top">Syran Arab Republic</td></xsl:when>
		<xsl:when test=".[.='SZ']"><td valign="top">Swaziland</td></xsl:when>
		<xsl:when test=".[.='TC']"><td valign="top">Turks and Caicos Islands</td></xsl:when>
		<xsl:when test=".[.='TD']"><td valign="top">Chad</td></xsl:when>
		<xsl:when test=".[.='TG']"><td valign="top">Togo</td></xsl:when>
		<xsl:when test=".[.='TH']"><td valign="top">Thailand</td></xsl:when>
		<xsl:when test=".[.='TJ']"><td valign="top">Tajikistan</td></xsl:when>
		<xsl:when test=".[.='TK']"><td valign="top">Tokelau</td></xsl:when>
		<xsl:when test=".[.='TM']"><td valign="top">Turkmenistan</td></xsl:when>
		<xsl:when test=".[.='TN']"><td valign="top">Tunisia</td></xsl:when>
		<xsl:when test=".[.='TO']"><td valign="top">Tonga</td></xsl:when>
		<xsl:when test=".[.='TP']"><td valign="top">East Timor</td></xsl:when>
		<xsl:when test=".[.='TR']"><td valign="top">Turkey</td></xsl:when>
		<xsl:when test=".[.='TT']"><td valign="top">Trinidad and Tobago</td></xsl:when>
		<xsl:when test=".[.='TV']"><td valign="top">Tuvalu</td></xsl:when>
		<xsl:when test=".[.='TW']"><td valign="top">Taiwan</td></xsl:when>
		<xsl:when test=".[.='TZ']"><td valign="top">United Republic of Tanzania</td></xsl:when>
		<xsl:when test=".[.='UA']"><td valign="top">Ukrainian SSR</td></xsl:when>
		<xsl:when test=".[.='UG']"><td valign="top">Uganda</td></xsl:when>
		<xsl:when test=".[.='US']"><td valign="top">United States</td></xsl:when>
		<xsl:when test=".[.='UY']"><td valign="top">Uruguay</td></xsl:when>
		<xsl:when test=".[.='UZ']"><td valign="top">Uzbekistan</td></xsl:when>
		<xsl:when test=".[.='VA']"><td valign="top">Vatican City State</td></xsl:when>
		<xsl:when test=".[.='VC']"><td valign="top">Saint Vincent and the Grenadines</td></xsl:when>
		<xsl:when test=".[.='VE']"><td valign="top">Venezuela</td></xsl:when>
		<xsl:when test=".[.='VG']"><td valign="top">British Virgin Islands</td></xsl:when>
		<xsl:when test=".[.='VI']"><td valign="top">Unites States Virgin Islands</td></xsl:when>
		<xsl:when test=".[.='VN']"><td valign="top">Vietnam</td></xsl:when>
		<xsl:when test=".[.='VU']"><td valign="top">Vanuatu</td></xsl:when>
		<xsl:when test=".[.='WF']"><td valign="top">Wallis and Futuma Islands</td></xsl:when>
		<xsl:when test=".[.='WK']"><td valign="top">Wake Island</td></xsl:when>
		<xsl:when test=".[.='WS']"><td valign="top">Samoa</td></xsl:when>
		<xsl:when test=".[.='YD']"><td valign="top">Democratic Yemen</td></xsl:when>
		<xsl:when test=".[.='YE']"><td valign="top">Yemen</td></xsl:when>
		<xsl:when test=".[.='YU']"><td valign="top">Yugoslavia</td></xsl:when>
		<xsl:when test=".[.='ZA']"><td valign="top">South Africa</td></xsl:when>
		<xsl:when test=".[.='ZM']"><td valign="top">Zambia</td></xsl:when>
		<xsl:when test=".[.='ZR']"><td valign="top">Zaire</td></xsl:when>
		<xsl:when test=".[.='ZW']"><td valign="top">Zimbabwe</td></xsl:when>
		<xsl:when test=".[.='UK']"><td valign="top">United Kingdom</td></xsl:when>
		<xsl:otherwise><td valign="top" bgcolor="red"><font color="silver"><marquee>Unknown Country <xsl:value-of select="." /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="InvoiceDate">
	<td><xsl:eval>DateFormat(nodeTypedValue)</xsl:eval><xsl:eval>TimeFormat(nodeTypedValue)</xsl:eval></td>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="DiscountTreatment">
	<xsl:choose>
		<xsl:when test="@stdValue[.='UN']"><td>Line item net unit price</td></xsl:when>
		<xsl:when test="@stdValue[.='UG']"><td>Line item gross unit price</td></xsl:when>
		<xsl:when test="@stdValue[.='TN']"><td>Line item subtotal net amount</td></xsl:when>
		<xsl:when test="@stdValue[.='TG']"><td>Line item subtotal gross amount</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Discount Treatment <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="TaxTreatment">
	<xsl:choose>
		<xsl:when test="@stdValue[.='NIL']"><td>Line item amounts are net amounts, and tax is calculated at invoice level</td></xsl:when>
		<xsl:when test="@stdValue[.='GIL']"><td>Line item amounts are gross amounts, and tax is calculated at invoice level</td></xsl:when>
		<xsl:when test="@stdValue[.='NLL']"><td>Line item amounts are net amounts, and tax is calculated at line level</td></xsl:when>
		<xsl:when test="@stdValue[.='GLL']"><td>Line item amounts are gross amounts, and tax is calculated at line level</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Tax Treatment <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="TimeRelation">
	<xsl:choose>
		<xsl:when test="@stdValue[.='1']"><td>Reference date</td></xsl:when>
		<xsl:when test="@stdValue[.='2']"><td>Before reference date</td></xsl:when>
		<xsl:when test="@stdValue[.='3']"><td>After reference date</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Time Relation <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="TypeOfPeriod">
	<xsl:choose>
		<xsl:when test="@stdValue[.='CD']"><td>Calendar day</td></xsl:when>
		<xsl:when test="@stdValue[.='DW']"><td>Working day</td></xsl:when>
		<xsl:when test="@stdValue[.='M']"><td>Month</td></xsl:when>
		<xsl:when test="@stdValue[.='W']"><td>Week</td></xsl:when>
		<xsl:when test="@stdValue[.='Y']"><td>Year</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Type of Period <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="PaymentTermType">
	<xsl:choose>
		<xsl:when test="@stdValue[.='1']"><td>Basic</td></xsl:when>
		<xsl:when test="@stdValue[.='3']"><td>Fixed date</td></xsl:when>
		<xsl:when test="@stdValue[.='8']"><td>Basic discount</td></xsl:when>
		<xsl:when test="@stdValue[.='10']"><td>Instant</td></xsl:when>
		<xsl:when test="@stdValue[.='22']"><td>Discount</td></xsl:when>
		<xsl:when test="@stdValue[.='OTHER']"><td><xsl:value-of select="." /></td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Payment Term Type <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="CardType">
	<xsl:choose>
		<xsl:when test="@stdValue[.='VS']"><td>Visa</td></xsl:when>
		<xsl:when test="@stdValue[.='AMEX']"><td>American Express</td></xsl:when>
		<xsl:when test="@stdValue[.='MC']"><td>Mastercard</td></xsl:when>
		<xsl:when test="@stdValue[.='DINERS']"><td>Diners Card</td></xsl:when>
		<xsl:when test="@stdValue[.='DSCVR']"><td>Discover</td></xsl:when>
		<xsl:when test="@stdValue[.='OTHER']"><td>><xsl:value-of select="." /></td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Payment Term Type <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="Date">
	<xsl:choose>
		<xsl:when test="@stdValue[.='STRT']"><td>Start Date/Time</td></xsl:when>
		<xsl:when test="@stdValue[.='END']"><td>End Date/Time</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Date Type <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="PartNumDetail">
	<xsl:choose>
		<xsl:when test="@stdValue[.='BP']"><td>Buyers Part No</td></xsl:when>
		<xsl:when test="@stdValue[.='VP']"><td>Vendors Part No</td></xsl:when>
		<xsl:when test="@stdValue[.='CC']"><td>Industry commodity code</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Part Number Type <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="UnitOfMeasure">
	<xsl:choose>
		<xsl:when test="@stdValue[.='EA']"><td>EA</td></xsl:when>
		<xsl:when test="@stdValue[.='DY']"><td>DY</td></xsl:when>
		<xsl:when test="@stdValue[.='C']"><td>C</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Unit of Measure <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="TaxFunction">
	<xsl:choose>
		<xsl:when test="@stdValue[.='5']"><td>Customs duty</td></xsl:when>
		<xsl:when test="@stdValue[.='7']"><td>Tax</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Tax Function <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="TaxType">
	<xsl:choose>
		<xsl:when test="@stdValue[.='VAT']"><td>Value Added Tax</td></xsl:when>
		<xsl:when test="@stdValue[.='GST']"><td>Goods and Services Tax</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Tax Type <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="TaxCategory">
	<xsl:choose>
		<xsl:when test="@stdValue[.='A']"><td align="right">Mixed</td></xsl:when>
		<xsl:when test="@stdValue[.='E']"><td align="right">Exempt</td></xsl:when>
		<xsl:when test="@stdValue[.='G']"><td align="right">Free export item</td></xsl:when>
		<xsl:when test="@stdValue[.='S']"><td align="right">Standard</td></xsl:when>
		<xsl:when test="@stdValue[.='Z']"><td align="right">Zero</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Tax Category <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="SpecialCond">
	<xsl:choose>
		<xsl:when test="@stdValue[.='6']"><td>Subject to bonus</td></xsl:when>
		<xsl:when test="@stdValue[.='7']"><td>Subject to commission</td></xsl:when>
		<xsl:when test="@stdValue[.='11']"><td>Price includes excise</td></xsl:when>
		<xsl:when test="@stdValue[.='12']"><td>Price includes tax</td></xsl:when>
		<xsl:when test="@stdValue[.='18']"><td>Item subject to national export restrictions</td></xsl:when>
		<xsl:when test="@stdValue[.='97']"><td>Promotional price</td></xsl:when>
		<xsl:when test="@stdValue[.='94']"><td>Service</td></xsl:when>
		<xsl:when test="@stdValue[.='103']"><td>Loan</td></xsl:when>
		<xsl:when test="@stdValue[.='104']"><td>Rental</td></xsl:when>
		<xsl:when test="@stdValue[.='105']"><td>Processing</td></xsl:when>
		<xsl:when test="@stdValue[.='106']"><td>Exchange</td></xsl:when>
		<xsl:when test="@stdValue[.='140']"><td>Return of goods</td></xsl:when>
		<xsl:when test="@stdValue[.='OTHER']"><td><xsl:value-of select="." /></td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Special Condition <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="PaymentMean">
	<xsl:choose>
		<xsl:when test="@stdValue[.='10']"><td>Cash</td></xsl:when>
		<xsl:when test="@stdValue[.='20']"><td>Cheque</td></xsl:when>
		<xsl:when test="@stdValue[.='30']"><td>Credit transfer</td></xsl:when>
		<xsl:when test="@stdValue[.='ZZZ']"><td>Credit/Debit card</td></xsl:when>
		<xsl:when test="@stdValue[.='OTHER']"><td><xsl:value-of select="." /></td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Payment Method<xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="RefDate">
	<xsl:choose>
		<xsl:when test="@stdValue[.='5']"><td>Date of invoice</td></xsl:when>
		<xsl:when test="@stdValue[.='9']"><td> Date invoice received</td></xsl:when>
		<xsl:when test="@stdValue[.='21']"><td>Goods received by buyer</td></xsl:when>
		<xsl:when test="@stdValue[.='26']"><td>Date of arrival of transport</td></xsl:when>
		<xsl:when test="@stdValue[.='81']"><td>Date of shipment (as evidenced by transport documentation)</td></xsl:when>
		<xsl:when test="@stdValue[.='82']"><td>Date payment due</td></xsl:when>
		<xsl:otherwise><td bgcolor="red"><font color="silver"><marquee>Unknown Reference Date <xsl:value-of select="@stdValue" /></marquee></font></td></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="Ref[@stdValue='STOP']">
	<xsl:choose>
		<xsl:when test=".[.='O']">STOPOVEROK</xsl:when>
		<xsl:when test=".[.='X']">STOPOVERNOK</xsl:when>
		<xsl:otherwise></xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates />
</xsl:template>

</xsl:stylesheet>


